# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The Qt graphical interface for the control panel for Ubuntu One."""

from PyQt4 import QtGui, QtCore


def uri_hook(uri):
    """Open an URI using the default browser/file manager."""
    url = QtCore.QString(uri)
    QtGui.QDesktopServices.openUrl(QtCore.QUrl(url))


def pixmap_from_name(icon_name):
    """Build a QtGui.QPixmap from an icon name.

    If the theme does not have the icon, build one using the resources images.

    """
    pixmap_name = ":/%s.png" % icon_name
    return QtGui.QPixmap(pixmap_name)


def icon_from_name(icon_name):
    """Build a QtGui.QIcon from an icon name.

    If the theme does not have the icon, build one using the resources images.

    """
    if QtGui.QIcon.hasThemeIcon(icon_name):
        icon = QtGui.QIcon.fromTheme(icon_name)
    else:
        pixmap = pixmap_from_name(icon_name)
        icon = QtGui.QIcon(pixmap)

    icon.icon_name = icon_name

    return icon
