# -*- coding: utf-8 -*-

# Authors: Manuel de la Pena <manuel@canonical.com>
# Authors: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Main method to be used on linux."""

import sys

from dbus.mainloop.qt import DBusQtMainLoop
from PyQt4 import Qt, QtCore

# Module used to include the resources into this file
# pylint: disable=W0611
from ubuntuone.controlpanel.gui.qt.ui import images_rc
# pylint: enable=W0611


def main(switch_to='', alert=False):
    """Start the Qt reactor and open the main window."""

    # The DBus main loop MUST be initialized before importing the reactor
    DBusQtMainLoop(set_as_default=True)

    # The app variable should be in scope of the reactor.run()
    # pylint: disable=W0612
    app = Qt.QApplication(sys.argv)

    # Apply Style Sheet -- ONLY FOR DEBUGGING PURPOSES
    qss = QtCore.QResource(":/ubuntuone.qss")
    app.setStyleSheet(qss.data())

    # The following cannot be imported outside this function
    # because u1trial already provides a reactor.
    # pylint: disable=W0404, F0401
    from qtreactor import qt4reactor
    qt4reactor.install()
    from twisted.internet import reactor

    # pylint believes that reactor has no run nor stop methods. Silence it.
    # pylint: disable=E1101
    from ubuntuone.controlpanel.gui.qt.gui import MainWindow
    window = MainWindow(close_callback=reactor.stop)
    window.show()

    reactor.run()
