# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The base widget for the Control Panel tabs."""

from PyQt4 import QtGui

from ubuntuone.controlpanel import backend
from ubuntuone.controlpanel.gui.qt.loadingoverlay import LoadingOverlay


class UbuntuOneBin(QtGui.QWidget):
    """The base widget for the Control Panel's tabs."""

    ui_class = None

    def __init__(self, parent=None):
        """Initialize the UI of the widget."""
        QtGui.QWidget.__init__(self, parent)
        self.ui = None
        if self.ui_class is not None:
            # self.ui_class is not callable
            self.ui = self.ui_class.Ui_Form()
            # pylint: disable=E1102
            self.ui.setupUi(self)

        self.overlay = LoadingOverlay(self)
        self.overlay.hide()

        self._is_processing = None
        self.is_processing = False

        self._setup()
        self.backend = backend.ControlBackend()

    def _get_is_processing(self):
        """Get the value of is_processing."""
        return self._is_processing

    def _set_is_processing(self, new_value):
        """Set the value of is_processing.

        If is_processing, disable the UI and show a spinner.
        If not is_processing, enable the UI and hide the spinner.

        """
        self.overlay.setVisible(new_value)
        self.setEnabled(not new_value)
        self._is_processing = new_value

    is_processing = property(fget=_get_is_processing, fset=_set_is_processing)

    def _setup(self):
        """Do some extra setupping for the UI."""

    # Invalid name "showEvent"
    # pylint: disable=C0103

    def showEvent(self, event):
        """Load info."""
        self.load()
        event.accept()

    # Invalid name "resizeEvent"
    # pylint: disable=C0103

    def resizeEvent(self, event):
        """Resize the overlay to fit all the widget."""
        self.overlay.resize(event.size())
        event.accept()

    def load(self):
        """Load the widget with specific info."""
